@@ -24,6 +24,9 @@
 
 from cStringIO import StringIO
 import datetime
+from itertools import (
+    permutations,
+    )
 import os
 import stat
 import warnings
@@ -31,9 +34,6 @@ import warnings
 from dulwich.errors import (
     ObjectFormatException,
     )
-from dulwich._compat import (
-    permutations,
-    )
 from dulwich.objects import (
     Blob,
     Tree,
